@@ -9,6 +9,7 @@ coxreg <- function (formula = formula(data),
                     x = FALSE,
                     y = TRUE,
                     boot = FALSE,
+                    efrac = 0,
                     geometric = NULL,
                     rs = NULL,
                     frailty = NULL,
@@ -140,6 +141,7 @@ coxreg <- function (formula = formula(data),
                       max.survs,
                       method,
                       boot,
+                      efrac,
                       calc.hazards = TRUE,
                       calc.martres = TRUE,
                       control,
